@@ -8,6 +8,8 @@
 package PDL::Ngrams;
 use strict;
 
+our $VERSION = 0.03;
+
 ##======================================================================
 ## Export hacks
 use PDL;
@@ -26,8 +28,6 @@ our %EXPORT_TAGS =
    Func => [@EXPORT_OK],               ##-- respect PDL conventions (hopefully)
   );
 
-our $VERSION = $PDL::Ngrams::Utils::VERSION;
-
 ##======================================================================
 ## pod: header
 =pod
@@ -170,11 +170,7 @@ sub ng_rotate {
   my $N     = pop(@adims);
   my ($i);
   foreach $i (0..($N-1)) {
-    ##-- the following line pukes on cpan testers 5.15.x with: "Can't modify non-lvalue subroutine call at ..."
-    #$rtoks->dice_axis(-2,$i) .= $toks->dice_axis(-2,$i)->xchg(-1,0)->rotate(-$i)->xchg(0,-1);
-    ##
-    my $rtoks_i = $rtoks->dice_axis(-2,$i);
-    $rtoks_i .= $toks->dice_axis(-2,$i)->xchg(-1,0)->rotate(-$i)->xchg(0,-1);
+    $rtoks->dice_axis(-2,$i) .= $toks->dice_axis(-2,$i)->xchg(-1,0)->rotate(-$i)->xchg(0,-1);
   }
   $rtoks = $rtoks->xchg(-1,0)->slice("0:-$N")->xchg(-1,0);
 
@@ -202,7 +198,7 @@ from a PDL vector, before rsp. after constructing a vector of N-gram vectors.
 
 =for sig
 
-  Signature: (toks(NToks); indx boffsets(NBlocks); delims(NDelims); [o]dtoks(NDToks))
+  Signature: (toks(NToks); int boffsets(NBlocks); delims(NDelims); [o]dtoks(NDToks))
 
 Add block-delimiters (e.g. BOS,EOS) to a vector of raw tokens.
 
@@ -216,7 +212,7 @@ See L<PDL::Ngrams::ngutils/"ng_delimit">.
 
 =head2 ng_undelimit
 
-  Signature: (dtoks(NDToks); indx boffsets(NBlocks); int NDelims(); [o]toks(NToks))
+  Signature: (dtoks(NDToks); int boffsets(NBlocks); int NDelims(); [o]toks(NToks))
 
 Remove block-delimiters (e.g. BOS,EOS) from a vector of delimited tokens.
 
@@ -251,13 +247,13 @@ perl by Larry Wall.
 
 =head1 AUTHOR
 
-Bryan Jurish E<lt>moocow@cpan.orgE<gt>
+Bryan Jurish E<lt>jurish@ling.uni-potsdam.deE<gt>
 
 PDL by Karl Glazebrook, Tuomas J. Lukka, Christian Soeller, and others.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2013, Bryan Jurish.  All rights reserved.
+Copyright (c) 2007, Bryan Jurish.  All rights reserved.
 
 This package is free software.  You may redistribute it
 and/or modify it under the same terms as Perl itself.
